@@ -1,6 +1,6 @@
 package Catalyst::Log::Log4perlSimple;
 BEGIN {
-  $Catalyst::Log::Log4perlSimple::VERSION = '0.2';
+  $Catalyst::Log::Log4perlSimple::VERSION = '0.3';
 }
 
 use 5.010;
@@ -174,8 +174,12 @@ sub BUILD {
             log4perl.appender.PROXY.layout=PatternLayout
             log4perl.appender.PROXY.layout.ConversionPattern=%d{HH:mm:ss} %18c{2} [%4L]: %m%n
         });
-        $self->proxy(Log::Log4perl->appender_by_name('PROXY'));
     }
+    my $proxy = Log::Log4perl->appender_by_name('PROXY');
+    unless ( UNIVERSAL::isa($proxy, 'Log::Log4perl::Appender::CatalystProxy') ) {
+        die q{Can't find the PROXY Log4perl Appender};
+    }
+    $self->proxy($proxy);
 }
 
 
